function [matrix,projection,vector]=multipletreduction(m2d,zerorow)

% Multiplet reduction algorithm following the recipe described in 
%
% B. Luy, 
% J. Magn. Reson.
%
% Starting from the spectrum (m2d) and the user-defined zero-row (zerorow) in the
% J-dimension, the algorithm searches for fourfold symmetry patterns.
% All fourfold symmetric entities are projected to the central chemical shift
% in a 2D matrix conserving the multiplet pattern in the J-dimension (projection) 
% and in a vector representing a "decoupled" 1D-spectrum (vector).
% The residual spectrum containing all patterns incompatible with the fourfold 
% symmetry are stored as well (matrix).
%
% For the algorithm to be of use the following points should be fulfilled:
% - the 2D spectrum (m2d) must have identical resolution (Hertz per point) in each dimension.
% - it is expected that the zero-frequency in the indirect dimension (defined by zerorow) is in the
% center of the J-dimension, only shifted by maybe one point if there is an even number of rows.
% - consider using a reduced data matrix (m2d) for the 2D spectrum in which as few as possible artefacts
% are contained and where regions without signals are cut out as far as possible since these areas
% will only contribute to an increased noise/artefact level. With fewer points the algorithm is also
% much faster.
%


% Initialization, setting the limits of potential fourfold squares (circles)

rmax=min(size(m2d,1)-zerorow, zerorow);
cmin=1;
cmax=size(m2d,2);
vector=zeros(1,size(m2d,2));
projection=zeros(size(m2d,1),size(m2d,2));


% Loop over all potential fourfold squares

for limit=rmax:-1:0,
    limit
    for center=cmin+limit:cmax-limit,
        for lauf=limit:-1:0,

%           Special cases with points at the four corners of the square
            
            if lauf == limit | lauf == 0
                
%               Special case of single points along zerorow first

                if lauf == 0 & limit == 0
                    if m2d(zerorow,center) > 0.0
                        vector(1,center)=vector(1,center)+m2d(zerorow,center);
                        projection(zerorow,center)=projection(zerorow,center)+m2d(zerorow,center);
                        m2d(zerorow,center)=0;
                    end
                else
                  test=[m2d(zerorow+lauf,center-limit),m2d(zerorow-lauf,center+limit),m2d(zerorow+limit,center+lauf),m2d(zerorow-limit,center-lauf)];
                  low=min(test);
                  if low > 0.0
                    m2d(zerorow+lauf,center-limit)=m2d(zerorow+lauf,center-limit)-low;
                    m2d(zerorow-lauf,center+limit)=m2d(zerorow-lauf,center+limit)-low;
                    m2d(zerorow+limit,center+lauf)=m2d(zerorow+limit,center+lauf)-low;
                    m2d(zerorow-limit,center-lauf)=m2d(zerorow-limit,center-lauf)-low;
                    vector(1,center)=vector(1,center)+4*low;
                    projection(zerorow+lauf,center)=projection(zerorow+lauf,center)+2*low;
                    projection(zerorow-lauf,center)=projection(zerorow-lauf,center)+2*low;
%                    projection(zerorow+limit,center)=projection(zerorow+limit,center)+low;
%                    projection(zerorow-limit,center)=projection(zerorow-limit,center)+low;
                  end
                end

%           General cases with 8 points on the square (circle)
            
            else
                test=[m2d(zerorow+lauf,center-limit),m2d(zerorow-lauf,center-limit),m2d(zerorow+limit,center-lauf),m2d(zerorow+limit,center+lauf),m2d(zerorow+lauf,center+limit),m2d(zerorow-lauf,center+limit),m2d(zerorow-limit,center-lauf),m2d(zerorow-limit,center+lauf)];
                low=min(test);
                if low > 0.0
                  m2d(zerorow+lauf,center-limit)=m2d(zerorow+lauf,center-limit)-low;
                  m2d(zerorow-lauf,center+limit)=m2d(zerorow-lauf,center+limit)-low;
                  m2d(zerorow+limit,center+lauf)=m2d(zerorow+limit,center+lauf)-low;
                  m2d(zerorow-limit,center-lauf)=m2d(zerorow-limit,center-lauf)-low;
                  m2d(zerorow+lauf,center+limit)=m2d(zerorow+lauf,center+limit)-low;
                  m2d(zerorow-lauf,center-limit)=m2d(zerorow-lauf,center-limit)-low;
                  m2d(zerorow+limit,center-lauf)=m2d(zerorow+limit,center-lauf)-low;
                  m2d(zerorow-limit,center+lauf)=m2d(zerorow-limit,center+lauf)-low;
                  vector(1,center)=vector(1,center)+8*low;
                    projection(zerorow+lauf,center)=projection(zerorow+lauf,center)+4*low;
                    projection(zerorow-lauf,center)=projection(zerorow-lauf,center)+4*low;
%                    projection(zerorow+limit,center)=projection(zerorow+limit,center)+2*low;
%                    projection(zerorow-limit,center)=projection(zerorow-limit,center)+2*low;
                end
            end
        end
    end
end

% residual spectrum without fourfold symmetries around zerorow

matrix=m2d;
            